.. aiothrift documentation master file, created by
   sphinx-quickstart on Fri Jan 13 12:14:05 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

aiothrift
=========

asyncio (:pep:`3156`) Thrift client and server library.


Installation
------------

The easiest way to install aiothrift is by using the packae on Pypi::

    pip install aiothrift

Requirements
-------------

- Python 3.4 +

Contribute
----------

- Issue Tracker: https://github.com/moonshadow/aiothrift/issues
- Source Code: https://github.com/moonshadow/aiothrift

Feel free to file an issue or make pull request if you find any bugs or have
some suggestions for library improvement.

License
-------

The aiothrift is offered under `MIT license`_.

----

Contents
========


.. toctree::
   :maxdepth: 2

   foreword
   quickstart
   tutorial
   license


API Reference
-------------

If you are looking for information on a specific function, class or
method, this part of the documentation is for you.

.. toctree::
   :maxdepth: 2

   api

.. _MIT license: https://github.com/moonshadow/aiothrift/blob/master/LICENSE

